translate.lang.vi

Package translate :: Package lang :: Module vi |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.vi

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Vietnamese language.
    23
    24  For more information, see U{http://en.wikipedia.org/wiki/Vietnamese_language}
    25  """
    26
    27  from translate.lang import common
    28  from translate.lang import fr
    29
    30 -class vi(common.Common):
    31      """This class represents Vietnamese."""
    32
    33      # Vietnamese uses similar rules for spacing two-part punctuation marks as
    34      # French, but does not use a space before '?'.
    35      puncdict = {}
    36      for c in u":;!#":
    37          puncdict[c] = u" %s" % c
    38
    39 -    def punctranslate(cls, text):
    40          """Implement some extra features for quotation marks.
    41
    42          Known shortcomings:
    43              - % and $ are not touched yet for fear of variables
    44              - Double spaces might be introduced
    45          """
    46          text = super(cls, cls).punctranslate(text)
    47          return fr.guillemets(text)
    48      punctranslate = classmethod(punctranslate)
    49